
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python FinTech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00y\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02e\x03d\x01'
        b'd\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadedsT.\x00\x00PYARMOR\x00\x00\x03\x07\x00B\r\r\n\t4\xe0'
        b'\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x14.\x00\x00\x00\x00\x00\x00Q\xa7ydKG\x11\xa2q^\x16|\x1b\xceT\xc6\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf2\x8f\x02\x1eE\xf1'
        b"\xfa,A\xaf\x82^`9\x84\xd4\xeeW\xb2\xb1\x89\x90\xcfli\xf1\xce\xdc\xcf\xc0\xd45\x7f\x07\x8b\x0f\xe1\xdf\x02\x1d'/\xb8:c\xe7Qp\xb5#\xf1\xb4\x9fJ\x1c(\x83V\xc3\xd8\xbf\x93u\xbe\x82@\x9b\xc7\xaa\xd5"
        b'7\x84\xaf/!Y(79\xe5&y%s>P>R\xef/K\x85\xf1fC\xc5\x9fM\x11I\x07\x1fp\xc2\xca8\x86\x17\x01\xac\xba2i\x1f\xfb\x0c\x9fY@\x96\xb7~~\xff+\xd9O~\x95\x04\x9d\x0eQ\xf3'
        b'*L\xdc@Z@\xd2\x93\xa9\xfd=\xde\xe4O\xc5/LJ\xf3s\xc4\x10/6\xb0\xa75j=ya\xa4\xa0\xac\x90\x95A\xf160\x1e\xc2\xc3\x10\xd8\xdfz\xa2\xf0\xe3\xfeOr_\x97\x7f\xef\xa1\xbe\xc5\xe5\xaf]\xf4'
        b'\xd2\xa7\xb6\x06\xd4\xf3\xba\x7f\xa3\x8a\xf0\x06\xfc\xc3\xe0\x04\x00\xf2\x1f\xb5o\xebW\xe0\x11\x01\xd8+\x81\xbb"\xb2\x18,h\xef\xb8\xa0~5\x1f\x1b\xb7\xd8s\xf1\x16]M\x91}\x14z\x88\xa99\xbe\xab\xb4\xe6\xf4\xb3\x91\xb9'
        b'\xfa\x01P\xd5\xee\xaa\x90\xb8\xb0\xc5\xc5Zz3p\x01\xf7A_%^6\xe0&\x08\xd6Z\x89\x97\xc6c>\x9e\x18\xcd\x10u\xf9\x05\xf5\xae\x06\xc7\xdf\x14dD\xbfu&(w_!\xf7\xd7\xee\x11\xf6AQV\x9b\x13'
        b"\xd7\x15\xc2\xa4*R&O\xe6yAk\x83\r\xb7\xc5\x8e\xad\xb0\xf0\xf398\xfb\xf8\xd2j\x82'\xe1\xde\xb8\x95\xeaC+5P\xf6l\x02\xfd\xd6PKq\xd6>\x16MIC\x89N\xd5\xaaf\xd9\x8dh\xfa\xaeY3"
        b"\xad\x9c\xb2\x86\xa1\xfc(\xb5UB\x9a\xf2v.4=W\xe6\x00u\xe2rD\tiNK8\x0c \xab\xce\xea\x1d\x96\xe2^x\xd4`\x9f\x8a\x92z\xa4\x11\x11\x12\x91\x89y\n\x02\xc8\xcb\xd7\xe1'\xe7\xa2\x9c\xac\x82\x18"
        b'Y\x8a/DS\x94 \x8d\xcci2\xf5\x00\xa7\xee\r)\x07"+*\xfb\x1c\xfe\x91^\x11\x9d\xc4\xf6\xd8\r\x1b\x19\xf0P\xc8\xe6s\x8cV4\xb0/\xab\x15\xe0\xc7 D\x1f\xe2\xbd,\xdf\xb3\x86K0\x08g\xa1\xf7E'
        b'1\x03\xb5\r\xa8\xd1\xde\xc3\xff\x05,\x8b\xaa\x83\xd9\xde\xff\xda\xd3\x00i+\xda\x05\xb4\x02\x85)jS\xb4\xc8\xd5 \xa9\xeeqX|-\xb1T\x95\xde\xe3\xa2\xd0a\x8b\x86EN\xccj,1Q\x95}\xc3\xc5\x1e\x9ag'
        b'\x871a \xed\x80\xdb\xa3\x90\xa4\x89\xd2_\x0c2\xdel\xf2\x92\xd3\xaf\xb4\xaa|\x1e\x1fg\xe0\xaf\xa2\x8c\\\xc8\x88\xe2gJV\x18u\xd5\x91M\xa0M\xf4\xbb\x9b#V\x01-KnKdh\xc9\x18\xe4\xf4"\x17@'
        b'\xaa\x97j\t+Z\xf4.\xe10\xe4U0e\xd0\xd8#G\xd71\xfa\r\xe7 ^l\xaf\xd1\xe2\x15=\x93\x81\x06\xab\x99\xe1}I|\xe8?++9\xc57hJA\x97\xff\xd6\x14\xb6u\xeb\x99Ivor\xf4\xea'
        b'\xf3Q\x03m\x0e\xd8\xad\xb8\xf7\xa0\xad`\xc7fW\x03\x0f\x0f!\xc4\xf8\xc4e\x1c1\x8d\xf1\xa4[/6w\x08.\x9e\xe8\xa9\xbbM\x8e7N_\x9d\x0e\xf0#\xc9\xd2\x1d1G\x10\xa8\xe3\xddz\x0c\xf4\xc8+_\xdfY'
        b'*\xdc\x9f\xda/\x0c\xd8\\|\xef\xf4\x15\xe1\xca\xa3\xf7\xf0\x15p\xca0q\x9d\xd5-H\xc4\x99z8d\x05\xabua\xc6\xfe\x0b\x8c\xab\x08\xe62\x92\x12\x81\x9f?\xab\x07"\xeb8\xc4\x96\x82\x02\xc4%\xc7\xa5\x8e\xfd\xdf'
        b'\xeb_\x1e\x8a\xdd\xba\xc8\xd0\xd5:_H\xf8\x92p\xb2\x8fL\xcfxd.\x12\x8fSj\x03D\x0b<\xf0ln\xcb\xa9@\x0e\xa3\x14X\x16\xddb\xe6\xbb\xb5\xe2\x99\x9d\xa0\xae.\xfc4\xdf\xe3N\xa4b\xd6\x19\x0c\x16\x9b'
        b'\xf9\xd7\xde\x8e\x11\xf0\xb41\x12\x1e\x7f\x00#\xa2\x87HuS\xf3^;\xa3nIi"\xac[\xd2\x01|p\xb1\xdcq\xd1u\xe02ApnH\xd2\x11\xd6S\xb7v\x81\xd7\x84\x05X\x9aUf(\xd3e\x97\xb2>_'
        b'\xc9w\xbd\xb7\x94\x15\xc7;\xf7\x95\xefha<\x7f\xff\xee*\xc5\xfd\x1f\x96Z\xd9w\xfc\x94\x87$\xef\xcdr\x1a\xfdz`6\x9c\xf6\x87\xef?\x9b\xee\x03\x00\x8fMM\xd1\xddq\xa1\xbd\x93\x9b\x8b\x19M\xb5#\xe6HF'
        b'\xba\x15\xe9\x93\x08}\x1dZ\x82\xe9un*$f\x80b\xcb\xb0\xf7B\x08\xa8\x1e\xbb\xf2\x1b:\xd8\xf08S\xb9\x93,\xa5\xae\xf2\x96\x02v\xf6\xf2\x99qQ\xd8\x95\xd6\xb4\x8f\xc1\xd6\x86R\x04\x9e\t\x9d\xac\xa7\x8c\x89\x92'
        b"\xf2w19\x1a\x9c\x82\xf3\xc48\xd0\xac<\x88`\x83l! 'i\xb0gm\xb1\x90S\xfe*\xe5Gs>r>Py\xa4|\xf3\xc1J\xcfz\xa2\xc9\x13+\xcac\x82\x9f\x93i\xb9\xae$3DS\x93\x0c\x19\xa9"
        b'\xe2\xc3|\x02\x84\x11\x83*N\x05\xc7\xfc\xa8\nQ\xa6\xb2O\x9c\x90\xebl\x19\x03\xf3\xbb\xcf\xdf\x02\xe5^%a\xbd\x7f4\xe2Z\xf1\x9b\xf3\xef\xa1\xc8\xfb\xa8!\xd3!\xc2\xfd\xd2+\xf4\xab\xd9\xd1\xa7\xcf\x0fa\x99%\x9c'
        b'r\xf6\xdc\x1dJS\x0e\xd8\xb1\xad>\xe4\xf9ER;\x8f\x85/ \xec\xdc|\xe0:2GP\x13\xb3c\xdf\x9a#\x19Ryk\xa4!\x83\xe3u\x0c\xc7\xa3\xa3`\x19\xa0\xe4\x8a\xff4z>\xce\xbb{\x89\xb6\x8e\x12B'
        b'\x13\xc9$\xfd\xac\xaf\xb6c\xf1\xb8\x03\x04\xb4\xeb\xd3\x16\x1b\x08\xff\x18g\xd8(\xb4X\x8f\xb0\x1c\xb2/\x13\xd8\xba\x12)\xb7\xc1\xb0\xda\xd4K\x836\xb2\xbb\xda=\xdb\xaf\x86\xbf\xf0\x9e\xb6.\x1b\xf4\xc2\xeb\x93w\xf2\xa6\r'
        b'\xbb\xdbi\xa4=\xe7\xc0\xc3\xa9/Y\xd7\x9c\x11\x9f\x08\xa6\x90?gY\xf4\r\xd9~7\xda \x91\xec\x91z\xc3\x82y\x8d\x05\x06\r\xbb\x9c\xb3c\xc9\xba>\xd2\xa6\x90\xbbU\xd5/\x82\xf2\xd9xS\xb8\xbc!\x1a\r;'
        b'\\\x85S\xde\xb1)9\x0fl\xbb\x99\xff\xacDd\x9b\xbb\x7f\x1c\xa1\xc9\x9d\x95A\xe4DE}\xdcd\xaf\xbe\x88\xde\x87\xd8\x8dG\x92\xb1\x18\xa0\xf7\xd7\xde\xf6\x97\xd9l\x0f1\x9c\xe8q5\xa1\xe5\x80\x9a\xa3\x8d\xb7\xe5\x97'
        b'5\x13\xf3\xc0\x1dL\n\x17\xd8R\xa9\xd2O{\xb4\x7f\x12\x1c\x1a\xba:\x89DA\x15\xcb\xc9\xd7 #\xa0"\x1e\x9f\xd5\xdc\xa8\xae\x86\xec!\xc1\x0f\xa5(\x9f\xe4\x950QG\x0c\xc2F|\x94!\x1c\xa6Z\xdcT\x17\xe2'
        b'\xd6ZvK|}Nq-\x91`y\x82ME\xdc>~\xb8\xb3\x1c [\xe4uB\xa7\xb6f\xb2\x06\xf5/\x17<\xc0\xbbp\x9b\xc8\xeb\xa5\xd7k\xeb#3X\x99\xbeV\xb0m\x94\xe3`\x94BN\x1a \x19\xd9;'
        b"\xb4x\xa6\xa6]\x9eA\xe0\xde\x88K\xb8\x94\x99\xeeE\x07\xb5\xbd=\xd6\xe9\xd3\xf4\xf2\xae\xcd\xc4L\x0e\xa4\x94\xba~z\xb2\xaaZ\xf5\x99 %\x10\xcd'\x16\xce\xc3\x92\xac\xeb\x97\xa9KCq\xd4&^\xed-\x01K,"
        b"\xdd\xd6{\xee6\xa06\x85J\xe6\xc1\x1c3\x93'\xa1[\xfbod\xfd\x1c\xd4\xe6v\xc4]\xc4V\xfd`\x8blfE\x1a\xd1F\xc6\x11S+\xae$\xdb\x95\xb6\x84H\xb0\x9d\xdcuS\x95\x84\xd8\xaf\xccx\xcal'I"
        b'\xebp\x9e\x8c\xf4\xf9QD\xe0\xba\xa2\xed\xb4k\x9a\xa8\xab\xd5\x00^\x865\xe8\xe0\xe7\xcf\xef\x15\xc5\x89R.-y\xb7-3\x01\xb1\x81\xf2\xbd\xd1\xee\xb0\xb4*^\xec\xa42r\x02\xa5}\x1d\xa4\xd4\xf9\x1aG\xa50\xe9'
        b'E\x8bR\xd6r\xd05\xcc\x00MOu%\xad\xd3\xc4\x9a\x06TJ4<\x8b\xe6\xc5e\x8b\x82e\xf3CR\xb7\x8f>\t\xb8\xab\x15\x87?\x0bWs\r\t\x92\xb7R\xe9|\x87\x89\xa2\xfbhXM]\xe2\xae\t\xf0\xd0'
        b'f\x96\xcc\x0f\x18\xd0Vf\xc6\x1b\x84Bb\xf6\xb9\xdd\xba\xecH\x8f\xf3(\x83\xe2\xb2\x897\x10\x98\xd4X.1\xe2\x10@\x85T\xc6\xb7\xbc\x92\xd8?\xfe\x06\xa4\x94f\xce\xf2\x81E\rv\xa8\xc6\xd7\xdaB\x10\xb9\xceZ'
        b';A\xcfc\x00\xb3\xab\x11\x9d\x9e\xa1W\xb7\x0e\r<\xe0\xdb\x1d\x84{&e\xdeBX\x9c\xd0(\xc2\x1f1\x99 J\xc0i\xe6\xa1\x1e\xd9fT\xdd\x1eZ\xf6\xdf\n\x00\x04(\x88\xbc\xf9p#\xee\xd0,\xe0\xdcNH'
        b'\xccA:I\xebg\xf9{\x0e\xed\x99\xcdMaw0sM\xa4l}\xfd\xc9\xe3\xabH\xcf|\xa8\xb5u`\xef\x0e\xf7\x92Y\x18*l\xe3?\xf4\xc7\x0b\xdeG\xdb\xdc\x1c;7(\xa5\xd7R\xf4\x80a\x9eg\xca\xfcH'
        b'\x0c\xc0\xb2\xe9w\xec$\x1f\xa3\xe8\xc1e\x14\r\x12lC\x10\xedS\xdc\x92\x00j\xd4D\xcf\xc4kE\xa0:O\x9f\x02\xec\x01E\xcdh\xfbf\x97\xb0\xa3\xe5\xfavA\xbe\x89>\x06Si\\\xdc4\x06*9\xe7m\x85'
        b'\xf9\\\xa0\xb7\xe9(\x16\xc2W\xfb\xee\x08\x9e\xaa\x1f8d\x00.\x89\x96E\xafP\xa0<\xcb\xb4\xda3\xba\xc9c\x1a\x14\x17i=\x13G\x9a\n\xdd\xf6,\xc4\x1e\xa7\xe1vo\xad/\x98:\xfa\x13\xee\xd2\x84\x03\xe0_\xe8'
        b'Wsg\xd3:\x18\xa4\xe2"\x94I\x07\x04&\x13\x9b\xa6\xb2\x88\xae\xfcF\xa9n\x88j\xb6\x05<\x01s\r"\xf5\x05\xd7c\x1a\x9dx/\xcev\xd1\')\xba\x95\xd6\x99\x15\xe6\x9f\xe6\x84\\u\xde\xc8G\x0e\xb8\xb8\xe2'
        b'\xb6H\xfa\x9eD\xafiam\xc0r\xe5\xd9\xd9\x1fF)A\xbfJ+\x19h\x07\x82\xd9T\x8a\xc1\x1c\xa8Y\xe6?\x08\xe3\xdd\xb5\xafe\xf2\x1a\xac\xc1\x1b\xa7\x98\x9f\xc1G\xe0%\xa3F\x8e\x9e\x95\xcd\\\x10B\xaf\xfff'
        b'\x83\xab^\xe4\x8b\xfb\xd1\xae%gG\x00\x1d\x1c\x9a\xf4\x96\xeb\x8a\xee\xdd\xff\x06\x9f\x9b\x9e\x9c\x16\xe2\x8a\xe6\xae\x9d\xb0dX\xf2\xf30\xe8\xf4P\x0f\x0c\xb5qT\xb6\x8e6\x91\xf33\x1e\xbf\x04[\xcb^\xb0by\xa1\xb1'
        b'UeH\xa2R\xf5\x96c\xef\xe9\x00K\xda\xdaN\x1c#\xe6Z\xbd\xb7G\x8e\xa9\xd093\xads\xbdY\xd5\x16~\x9e\xb9\x95;\xddx\xf8\xcaY\xe6\xf1\xab\xadH\xf8#\xffycM\x9e=\xdd\xe4A\xfbp{\xcc\xa7'
        b'P^R\xad\xfa\x0c\xa5\xff\xf9^\xd3\xad\x92\xf7\x8c\x1eS+\xf4\t\xa0\xef\x99\x9fq\xaf\xaa|D\xa5\x1a\x0bYJfV\xf0\x0f]P\xd1\xa2\xec\xf4v\x16\x11\xe5\x08\xa6\xdd\x9f\x84\xecV\xc7S\xa4\xdb\xf1\x05\xa5s\x94'
        b'\xdb\xcf\x95\xb5D\x03\xb7\xbc80\x8a\xdaT\xd0\x94\t\xf1l\t\x1eh\xc9M\xa3\xc6h\xf8lt\x93\x85\x84A\x12\x14%\x9f\xb9\xbf\xfd\xb6we_\xc8l\x04\xca*L\x14\xc1@\r\xe6\x02\xdb\xd6\xe7\xff\xc1d\xfc\xfd'
        b'\xa0\xce":\xa7\x12\x9f\xd9\x94\xcd1\x101kB\x18R\xf0\x13\xe8\xa5^\xda$k^\xb6\xa6\x17\xb4\xce7k!O>\xa3\x08O\x1c\xd7\xa8^\xa5\x8f4&\x8d\xcd\xaa\x9f\xa6\xa2@\xcaJ\x1f4\x06(\x166Vd'
        b'|\x8a\x02\xe7\xd1\x07\x95\x1c\xdei\xf82\xa8\xc8\xb2\xd3\xa3\x8f\xf6;\x19\xd2\xf8\x97\x89\x9ffz\xa9\xa4\xeb\xb0\x11\xc7,\xfc\xd9C\xdcF&\xbcq\x99\x93\xc1+kj\xc8\xab\x1e\xe1\xde\x19"\'4\xb2s\xe7.\xf0\xd8'
        b'\x96D\x8c\x07 \xe6%\xed\xd2\xab\n\x10\x9e\x06Fj;\r\xf7\x96\x15\xf3r\xa6"\xb0\x1d\x9f\xf2\xd6\xec\xbdF\x8a\xf1\x15\xd0\x90\x15RO\x08$I{\x0b\x97~bD\xe9\xf7\xd2@\xd5\xf0}\xea\xbarFB\x08V'
        b'\x9b\x9e>\r\xaf\xc6\xc5\xa2\xcdB\x03\xb1$F\xa8X\x94~\x0f\n9\x83\xd9\xaeW\xad\xda\x02\x84A\x8f\xc2n\xd3\xd4\x97\x9a\x953\xc2d\x0e\xd3\xc3\xc0\xfc"\xe3\xf0\xec\xe5\xaat\xb3\xe8\xad\xf3\x0f\xa9\x84\x19\xec\r\xf8'
        b'\x93\x82\xf2(W\x9f\x9d#\xda\xea\xa8\x13\xe3}9\xca\r/\xea\xe5x\xe6M\x84s\x10\x1e\xc54\xb5\x80\x0b\xf4`\xd2{\x0e\x02F\xce[\xc2\x9dh\x15H\xc5\x889\xf1\xcc\x1fi*\x12V\x8e\xc9D\xaa\xedM"N'
        b'\xfc\xe8\rj\x1di\x1c\x9d\x86\x17\x8a/\x1c\xa7\x99C\x88\nf\x81]\xca\x8e\xce\xe1\xc2\xae\xc2\x12\xd1\x83\xb3\xf4\x1fe+M\xc2R\x132\xed\xc97\xabI\xeb\r\xb4J\xa5\xa2t\x07\x12AL0\x8b\xea\xf5\x13\xb0\xe4'
        b'Iv]\xcb\x14\xc4w\x98\xb7\xb6\xe0\x13Y\xd7\xab\x17{\xb7\x10\xf2\x85\xca\xf6\x13\x90\xb5\x82\xa7\x12\xe9o\xd3\xb4j\x81@4\xc1\tr\x14Z\xba\x86\xea\x9e\xe2s\xea\n-\x95\x11|\xfc\x9a\xf1\x19\x14\xec\xcf\x97\x9dg'
        b'\xf0F\xe5K\xf5\x9c;\xaf\x08"\xc5\xc9S\xf5\x16\xa0\xe3\t\x86\x04x7\xd4\xe3\xf9$E\x08\xfb\xaa\xb4\xd6\x93a/\xccb;\xf93\xd7%c;\xf9*\xf2\xf6\x86~\xa9-\x81\xb3\x88A\xe2\x9f\xfe7\n\x8a\xe8G'
        b'5M,\xadw\xed\xedfE9\xb3nN~\x84\xd6#\xe2\xe142<\xf2\xfe\xfd\xbe\xa5\x15z\x04\x02\xd6\xe6OP?\x0e\xd5\xfb\x17\x8a\xac\x88\x031G\xf2\xcf\x9b\xf2T\xaf\xf2\xf38\x0el\xdcr\xed\x1f\xa6d\x8d'
        b'\x8d\x1aX\x07z\xf7\xb0\x9b Hv\xa3\x06\r\x7fs\xb1(\x0e\x9aiA\x0c\xb5\x9bR\xa0o\xfbHp\xf4\x0c\x06\x0c\x8eGR\xcb^\x13\xaa\xb2`\xfaX\xc0\xf5\xbc\\xU\x02\xce\x13Z\xa7\xb0\xf0\xb5y|\xff '
        b"\xa9\x9d\xf9<;\xf7\xae,\x81\x0b\x98\x83\xf5^\x0f\xd1\xf5\x1f\xab\xa7\x11\xf6&d\x1a\xd9Q\xf0;a\x8b\x85\xfb\x03\xff\xa3jb\\\x0c\x96K\xa7\xba<R\xcf\xe1\xc5\xb4H\x152T';c\xb9\xc2\xe8\x02\xb1\xbb\xbe"
        b'\r\x9fv\xf1\x04M\xda\xcb|\xb6\x0f\xe1\xa6\xfa\x9c\xf9\xa4\xb9,\x15y\xf8;ER\x1a\x13\xb7:\x11\x95\x15#c.\xe3\x02\x15PES`\xc8x\xae\x1d\x93f\x91\xa2`H\xa0\xeb\r\x99\xb4\xcd\xd5\xdc \x08V9'
        b'\xa6\xfek\xf4\x93\x1a\xe5:Q\xf1\x8aD*k\x7fs\x12\xb1c\x8f\xef\x88\x9f\xf2\x8c\xaa8\xc6Yk\xf4^\x1d\xfa\xe0\x8dC?h\xea\x0c\x86\xd8\x82\xf6\xa3vg\xedIa\x98_\xd1J\xa0\xb2\xc7\xd23\xe6@\xb0\xa9'
        b'\x86\xdc\xac\x86\x1e\xe8\xff\xb8\x83S2\xdcV\xee/9\xd8\xb7q\xa5\xe84\x98X\x9a\x83\x90\x06e\xca]\x8c\x8a\x11Uy\x85\xe7\xc9\xd7\xef0gOj{\x11\xdc\r\x93\xd7\xf7\xb0\x19\xc3\xf8>\xe7?\x81M$@\xa9'
        b'\x83WI\xe5D\x9c\xcc\xfb\xaec\x1a\xf4\xbd\xaa\x1dG<e,\x88\xa1<\x83\xa6\xbf\xe7)\x86{\x12\x0e\xeaq7\xbc\xae\xa7A\xdfx\xcb\xbc#\xe6\xb3\xf6\x1f\x83^B\xb1\xabd\xdcsRvo\x87\x86Ck3|'
        b'\xec\xde\xd9.\x1d\x1e\x12&\xa7\xff\x95q\xf6\t@\xb5JU\xec\x08(\xe8\xdeIQ\x87Ap:\x17\x89\xd4\xa3\xf0\xd1\x0f\x1av,\xc2jh\xa4\x86\xb1ok\x13\xad\xa30\x8a0\x00w$\xef\xe7\x993\xf3~S\xed'
        b'\xb8\xb3\x8b\xebe\xe4\xb3\x02\xe5\x94\xe3j\xfd\xb3~\x1c\xa6\x12\xae=\xcc\xca\xc5\xda\xef\xe3\x99\xd8#Z\xb1\xaa\xdf\x14=\xd15\xeb:\x96\xfexbU+s\xa5\x96O\xe5\xd2Q\xc2\x05\x18\xd1kB\xfc\x01p\xcdRM'
        b'Q\x04\xf6+\x11\x9eS\xa9\xf9\x07\x1d\xd8\x18\xe9/A\xe3e\xd5\x1c5\x8b\x81\n\xd2\x08\xd7\xe4I\x01d\xcb\x18\x0c\x91\xbd\xd6\xa2\xedw\x07\xe1\x82\xf0-\x15\xc6 \x8a\xf2\xec{\xef\x1fX\x89\x8c\x1b\xdc\x91\x96V|='
        b"Q\xd6\xf5E\x98\n$\xa7\x12\x1cWE\x86\xfe-\xfd\xda\x04|\xe4\xc0\xc5c\xee\x05\xdc\xb0\xf8\xa4D\xf8\x85\xfc\xf4X\xef\xab\xc4\xa3+\xb9\xf0\xf1\xd6\x8aJ\x10\xca\xe1\x94\xbf'\xdf\xe6\xffm\x19s\x80N\xc0\xe1\\\x08"
        b"\x004<\x9b\xf4\xb4z\x99R\xd0\xce\x04#\x0fH\x91\x0b\x02\xfc\xb5\xf2\xe6X\xdc\xe6l'\x80\x91\x8dr\xbft\\\xdf\xa8\x8c\xd8*\xa4\xf4\xaa2z\x9f\xc0Q\xd6\x97\xdf\xe7\xfb\xd7A\x19*3\x98\xa8\x1e\x8a\xf7\xd3\x13"
        b' 9\xe1\x7f\xad|*\xdc\xf3\x85\x93u-\x85\xe0\x04\x05I\x9a\xab\xffm\xc9\x9e\xdc\x87P\xde\x81>\xd4\xc0\xf4k\x0c\xb9\t\xa4\xeb\xd5\xc6\xb1<\xcb!\n\xc7a~\xd9\x0e\xf5\x10\x9c}\x19\xdd\xdb\x0fsE\x950r'
        b"I[\x15\xcap'\x15\xce\x97\xe3Z\xda\x02vn\xe4\xaeW\x89\x8bF\xade\x1c5\xaej8[e\xc5\x1fQ.\xf7C\xc1m\x03\xaf{\x8c#\x08\xed\xc4\xa8\xa9\xf6\x15]\x85\x1c\xbb\xec\x83YW\xf4\x93\x02\xef\x8cO"
        b"Ke\x95\x04\xf0\xa2\xd79\xae\xeb<\x14\x8dO\x01\xd7\x9b'\xa5\xc6\xde\xc2\t\xc1v@\x1cG\x1c\x94\x04\xe42Q\xab\x93z_s,M-\x93|\xa2\x9b\x00\xf7\x7f\x82A\xa7\x02s^4\xc2:\x0c\xee\xe0h5\x82"
        b'\xa3\xbb\r\xd9\x9fvX\xb6\x7f\xdfS(\xa8\xb0\x88\xc1\x16\xe3a\xe3\x17R5:\x17z\x12]\xfb783G\x94\xa5\x1a\xac\x0f\xc5\x92\xff{7\xf1\xb5_#N\xfel\xc2\x0b\xe9(\xd1\xa9L\x7f\x9f5e\x99^\x06'
        b'I\x1dg\x89H\x07\xf0I\xaf\x999\xb3\x9a\n\xaa\xdb\xe3\x1c\xe3\x07\x83\x1d\xa6\x9e\x9c\xcf\x11\x93h\xc1\x0c\x8a`\xef\x06\xd1\xf0\x92\xcf\xbc\x14\x9f,\x88\x15\x90\xecFT\x1f!F\x11`\xac|}#\xcf\xfa+\xaa\xc2\x7f'
        b'\x00\xaa\xfd\xfe\xd3\xde\x06\x85\xeb\xfcPf\x82\x8b>\xab3R\x10o\xf2P\x0e\x8e\xa69\xa8-\xf0\xb3Fzx\xf5t\xd6\xb3\x82\xa9,Lv+\xffz5\xe6=\xcap\xa0\xa6\xc6o;(\xc5#\xd7\x1b\x7f\x8a\xf0\x9b'
        b'\xcb\x88LMn\xeb\n\xd9\x99x\x99\xeeU*\xe5bd\xfe\xc5\x8d\x01\x94\xa1\xd9\x96\xca\x0e\x800\x1d\xa8\x04\xc7+\xbdK\r\xe9\xb4U7\x9cc\x98\x10B][\xba\x91mTe\xf5\xa6\n\x9b\xf53\xac\x00I\x9at'
        b'\xa7\xcb\xc4\x95\x00\x15\xa9\xb0\xfc\xab\x0c\xb8\x9en\xcf\xe1q\xed\xe0\xbc\xbcG\xbfU6\x92\xdb\n<\x93\xa0M\xf4\x10\x197\rx\x08\xbb\xfbMO\xdbs\x91\xadR\xc11\x047j\xb5\x8d\x87uF\x0f;\xc4\x9a:\xe1'
        b'}J\xbd\x1d\xe5\xea\xa5U\xbb\xee\x88\xe4\x9ah\x96n\x83#\xdf\xa5\x8f\x0f\xeb\x90s\xe6\xd8\xee]\x94<\xda\xb7>\xaf\xbbH4s\xe4\xedU\xa6\xd3w\xec\xc2\t\xd4x&*\xd6\xf2\xde\r\xbc\xfe\xa7\xb8\xee\xafJ\xb8'
        b'\xdc\xef\xd4\x87\xf4wa\xd8\xdb\xe7\xc8\x02B[\xe4\xddN\xa9\\\xe9\xe2\x91\x9a\xf1\xb1\x11\xb4\x95\x9d\r2\xac\xb2\x0eqi\xed=\xa2\x7f\xdc\xf2\xde\xb3\xc7LT\xb7\x89\xbe\x80,\x07\xd7\xe5\x00\x82\x03`\nE\x88\xb1l'
        b'*k\\F\xb0Y93\xbd)\x97s\xf0\xab\xd5\xec\xbe\xe9?\x1c\xd8u,\x1d4o\x1esA\x86\x97m\x8eN\x93\xf2\t\x90\xe0\x86#\x17\x9df\xe2\xe4nF\xef\xf9\x19\x1b\xa6H17D\x9fB\x8c\x99\xb9\x98_'
        b'\xc5\xb01\xec\x9b\xf5\x07>\x16\x85\x8e\x0e\xddR\xf6\xc98\xaa\xed\xce\x9fH\xe0\xd3 \x8aW\xa5\xb6}\x07\xd5J\x05R\xf6\xd6\xb1\xe7\xcfw!P\x11\x13>\x96\x96U\x01=\xef[\r\xef_W)`\xb6u2w\xa1'
        b'Y"T\x0e\xa6\x8a2\xa5`\x01\xfctd\x87\xf2\xb5X8\xbd\x1b\xdf\xd6E;\xe2i\xc2\xcf;\xff\x8a\xbfe\xda!\xf9}\xcfHK\xbd\x8b\xc9\x06B\xfa\x0e[\x05$\xb7`\xbd\xcc\x7f9\xef\xd0\xe3zv\xfc\xb9\x0c'
        b'Y\xf0`\x91\x13\xeb\\\xf0\xb4x__\x00\xbb[M=\xea\xd9\xff\xd0\x87a\xe4I_\xf1\xca\xf0\xe0\xf6\xb1Qm\xd1\xa8\xccf\x1a5\x80\x80\xe9#-\x84\x8c\xf5\xd6%\x9d\x18\x90oD\x88\x1d)\x18\x13\x85\x01\xde\xaa'
        b'\x84\xdac\xf0\x80\xf4f%m\xe2\xc4\xd7\xaei\xdf\x8fSa\xe0\x8dV\xd3C\xa3\xf2f\xd9KC\xe4\xd4.\xcbK\xae\x15\x97\xf2\xd8\x15\xfd\xed\xb4!!k\x0c\xa7K\xad\xf0\x19\xd0\xd1^\xc9\x06\xe8\x92\x92\xe2|\xd9\xab'
        b'\xc5\x02Yu8\x84\xef\x8dV\x06\xe5\xebN\xce-Rp\xd9{\x03\xea\xb5o\x01;\xa8Y\xdf\x9c\x03\x9a\xcd\xf2\x9eh\x9b\x93\x12\n\xd7=\x90\xdd\xdfw\x1a\x88\x10\xd4\xb3?\xfdz\xc1\xa7<\xeaV\xe8\x1e\x00;!i'
        b'\x1ff\xce\xbfB\xaaD\xd7\xf4\x87\xec\xa66\xf2\x8a\xca\x87\x11m\xe3\xdf\x17Y\xe1\xea\xe6\x9aW\x97&\xefz\xe7;\xc3\xd8\xa5\x0c\xad\xe6\xe1\x17\xfd\x15\xb9\xbd\x0esh\xb9\xa0\xd20\xef\x124\xbb_0sR\xe2\xceI'
        b'\xf6\xd5M\xa6\x028\x11\x80(\xe2\xdesH\xcf\xc0H\xfb\xef\xde\xfb^M+!b\xc35\x8d3`\xa5IU\x84\xeb\xcd\xb4\xf3YTr;\xec\xdaI\xa3R=\xe5\x9f\x83\xb8g\x14l\xa2_\xaf?d\xf9\x00\x9b;'
        b"o\xecQ\x1b\xb7x\x1c\x8bv\xb1g\xaf\xa6\x9c\x10<Y\x9d\x14\x86\x85\xf4\xfda\x06\xe1f\xe8\xc7nZ\x0c'\\\xf9\r\x03\x95=\xcf\rJ\xdb[f\n\x9fS\xfa\x15\x89h1O\r)\xc5\x9bWI\x94\xd3D\xb9"
        b'\xf6\xdf\x1e\xa8\x106\x12\xb6\x87\xc1\tx\xf6\xfb\x04\xd3\x9e>k\x1f\x07\xde\xfa0T\xf2\xd3\x98m\x89\x95\xfcR^\x88\xa05\x18\xec\x05\x14}\xa56ec\x15M[HO\x0f\xc7\x0fv\xe0\xb7\xbd\xe3\xbc\x0b\xdf\xc3\x83'
        b'\xbfv$v<\x95\xec*hQ\xf3\xf8\xc4\x0c\x0e\x87\xe8\xdbD\xec"\x18\xc4\xf8\x9b\x1c|\x1f\xda\xa9Z\x1a\x8cap>\x00\xa5H\x8b\x0f.\x14W\xb3%N,N\x87\x1d\x17]\xc7\xc9\xf7\xee(\xec\xebwy\x85_'
        b'\xb7\x95\x9fY\xbe\xeajFs\x1f\x06\xa5\xf9\xfd\x96\x07\xcde\xcbB\xab\x1f\x80\xb5\xe1\xde@~tO\x06\x9d\x1a\x99wW\x1bl*\x9dA\x00\xe5\xce \xfc\xf0"\xe3\xaa\x90\xd1\xe1\x83d%k\xde\x13\x94]-G('
        b'\x84\x12_\xe1&\x81\xed\x8e\x17\xe0yx\xc2z\x9eM\x19\x986\x90^?\xcc\x93\xd5\xb1\xf8\xd6\x9a\xe9)\xe0>M\x96v\xe3\n\x02\xfe(\xccy\x0b\x1a\\\xc1\x02g,V\xca \x89\xf9_9\x1b\xeb\x8f{\xb1\x11\xba'
        b'\xe2\x88\x84K\xcd\\\xddS\xf9\x01w2\xed\xb5\xa3\xdetn\x96\xa6\x82\x17\xe2f\xe4\x96\xee}\x8d!1\x9a\x18k\x9d:\x94\x95\xb4W\xda`\x01d\xc3&\xb5\x06\x8d\x9f\x0cR\xde=?U\xea<S\xc0S\xac$-'
        b'\xb0BX\x85\xffm\x8c\xe17\xf8\xd2"\xff^4u\x8d\x18\xbcW^#\x825\xab(\xf0]\x15M\x82\x9bF\x8a\x0cHD\x89\x87\t\xa8X\x07\x0f\xb9\xd8\xc6/\xad\xf7\xd6\xe4\xf25\xe6\xd7\x1fd\xe3=;v\xc7\xab'
        b'\xd9M\x7fE\xa8a\xcd\xc8\xbaj\x19\x1118\x1aC\xe2\xaa\x1a\xfb\x86\xbd\x93\x92\xb6\x16g\x10\xdfV\xe91Y@\xa3\xbf@`NPd\xb6r\x88\xceV\xf8W\x9c,\xd5\x0e\x8fzO?\xf7p\xdfB\xa6bYj'
        b'M\xe8\xc4\xad\x17_\xbc\xe8\xf8D\xf0\x1e\xc5uw\xdeV\xe6\xbe\x06@\x11\xc2L\x0f\xd9\x80\xd1\x1b\x86\xc46O2PF\xf6e\xfa\xc2\n0q\xa8\xee.\xf1\x17\x02\xaa\x99\x1aJD\xa5\xfb\xf04\x1685E\xf4\xf1'
        b'_\x10\xf7\x1eg\x7fk\x81\xde!\xdc\x12\xe9\x9e{\xd7`\x93\x18\x10\x82\xdaG\xe9\xffWlUpTrF\xd1U\x06\xbe\x8b\x12\xfb\x0c\xd9hp\xa8\x00\x8b3\x8bra\xc0\xb4F\xc1\x90c\xc8\xc7\x1a\x870o\xea\xad'
        b"\xc3\xc0tC\xfd\xaf\x93\xc4\x8d#\x90\x9c\xe7X'\xbeX+(\x86\xb0p\xd0~-\x99@\xac\xc0\x86\r\x03\x90$x\x82\xc5\xe6\xe1 \xd3\x8b\x08<(\x9f)!.$\xf4\xb4\x03\x11>\x9f\x9f*\x1a\x8e\xf1\x14\x9eQ"
        b'\xd1M\xae\x03\x8a\xe4kHP(\x1c/\xd9\xec\xe1oG2\n\x85\x19\x18\xa5\xceF_s\xbd\xb0C\xc5>-\xf6n\xa7T\xf3V\xf3\x07\x93>,/\xce\xf4\xe8\xed\x9a\xfe"\xcd\x1a\xe1Z\xd5\r\xadh\xa4\xe8\x90\x1e'
        b'S(`\x1ct\xb7s\xdc\x88\x84*\xee\x05\x83KM\xc8\x1f\x1d\xcf\xdbi\xa6\x98UK\xc9\xf2\x9cM\x81/s*\xbfy\xce\xd5\xe5\xb5\x04\xdc0\xb2\x83\neX\xdc\xa7\xab) \xca/\xbcB\xb0\xe7\x06\xdd\xad\xaad'
        b'\xa8\xcc#\x00\xc1\xed\xb7~\r\xfe\x19\x8c\xc1\xc6\x9a\r\xb2\x00M\xc0q\xda\xee^"\xa2\xc3wST\x82h\xf0\xfd\xaa\x0f\x05\x9b\x92=\x94\xae\xc7\xeb\x0f\x0b\xa6,|\x9f\xcb\xaeHC \x85f\x9d\x8e\x8f\x03\xb5r\x82'
        b'\xb9C\xa4d\x03\x14AX\xe7\x9e\xd7\x1d\xe6\xc1&\x88L\xe0/\xfd\n+F3m\x1a\\\x16\xe0\xdd\xcd\n\xd0\xf7\xbc\xba\x16\x9ep\x7f\x12\x12@\xa5\xa49\xc7\x99\xdf\x1dt\x7f\xe9\xfa\xad\x0ber\xf0\xd2P\x82\xde\xbc'
        b'-\xb2\xf9\x825\x9d\\\xe8>eUsf\xeeq\xb9\xd1VFdN\xd8\x02\x01\xd3\x81!\xabf\x93\xd0\x85\x8cs0G}\xba\xd4\xd4\x19\x1f\xf9d\xc9S\x12\xf7\x06\x1cK\x12\r\xa3\x14\xd3T\x16\xd2\xc8\xcd0\x83\xa4'
        b'\xa8c\xe2k}O:%T\xcd\r\\\xf3X\xdd\xd9\x82\xb9\xc2\xbb\x8c\xfd\xf1\x9a\x17\xe6^\xd0cv\xf1s\xdaGl\x12xM\x13WON\x9do\xd7\xc6\xac\xa7\x8d\xf4\xe3\xdeY\x17\x14\xf6\xdbn\xfc\x9f\xe7z\xa5\x98'
        b'l\xb5\x85\xbf=^\xc6D\xf1c\x84\x95\xccH\xdcJ\x12\xf2\xce6\x1b|{t\x88Sg\xdd\x7fDY\xa4\x1f)D\x87\xd2\x9f\x13\x0b\xed\x94\x90\xe2/H\xc4\xc8\xf66F\xca\xce\xae\xc3A\xa8$~\x1aQ\xdd\xbfK'
        b'\xbe\xe5xw;\xc1_~FS\xcfW\xe0b\x05\xe5\xb6\xba[&\x85[)\xdb\x7f\xed\x8d\x8b\xa1\xeb\x16@\x1e\xe0+,\xdc\xd9\x1d\x83\x06\xc6#\x03T\xd4\xa2\x8bH\xb5\xc2c\x80\xa5\xe2\xdc\xc7\xd2#\x96\xb1\x11e4'
        b'\xd8dg\\j4\x01\x1c\x9bo\x18\x1c\xa4\r\x90v-\xf9\nY\xba\xa4M\x0fP?\x8aFm\x1cI\xb2\x15\x8a\xa0N\x99_>\n\xb6h\x08\xda\x1d\xbb4>\xa2\x10pt\x19\xcd\xce!L\x1b\xebb\xd2\x15\x1a2'
        b'\xb0\x03\xe9\x7fEX+Y\xfa\xce|{P\xdaR#\x9b!r=;\t;/^\xcd\xb9\x85\xbe\x06\x0f\xa16\xcb\x9a\xc3Ic<>\xfb<\x062\x9b\xc5N\xb3\xa1\xd4\x0fe\x87?Z\xf9v\n\xe5\xfd\x9c\x90\x88m'
        b'P\xe0\xe98^.\xc6\xf1\x03\xd4\x0bN\xb4\xe8\xcf\xf1e{\x97\xf7\xe4A\xc2c\x11\xb1NX\x9c!a\x82\xf1U\x9a\xb4yNM\xad\xd2\xea/a\xed\xe1\xee\xeaX\xb6\xf5\x19bQw\x99\x8a\xea%%\x97\xe0\xbac'
        b'Y\x88\x95\r|\xbf\x06>\xd9\x83\xc2E\x00\xe2#\x12\x8b\x91r\x13\x9bb\\\xca\xc3\xf2x\xd0\x0e\x1c\xe0\xc8\xe5T\xf6\x93Hk\x99\'"\xfa\xb8\x1f\xba\xf0k\xdbA\xa2xF\x80\xa5\xea\xeeA\xdb\xac\xb8\xa9]\xf1F'
        b'\x1a\xe8O\xd8\x8c+\x01\xaf\x11}\xc3c\x15\x1dnT\xd9\xac\xde)kb/3\xaa&3\xbd\xff\x1b=\xa2$\xd8\x87\x1f_2\nO\x87)\xf2\xd4z`\xa2\xa9\x80w\x85e\x1a\xb6iD\x99\xa4\xe2"\xcfI\xc6\xcc'
        b'\x83\x90\xbb\xd7\xd2\xd1\xb7\x174\x1b\x98\xcdb\x10\x985\\\xe3\xc3\t\x93\xb1Y\x97\x93\x93\xa5r\xf6\x0e\xb2\x94\xd7\xd1\x19\xcb\x7f\xfb\xaa\xe7*\x1e\xc4\x11\xc2\x8f\xfc\xa7N>\xc63\xfd\x18\x91u{s\xf6\n\xdd\x1eR&'
        b'\n\xac\t\xbb9\x88\x1e\xc3\xaeN\xa2\xf5\x04Js\x8a\xb1#\xe9\x80\xa6\x1f$\x1c+\nt_\xff.\xfa\xe4\xb7\x1e\xaa\x1cQ!\xc7\rsfs\xdfv\x8c\x1b\xab\xbf\x02\xbcq\xb2\xbb\xb4\xach\xff\xcb\x19\xf7\xefW\x0c'
        b'_\x89=$\x0c"\xd9\xb3\n<\xcc\xde\xe7\xac\xcf\xb8\xc7\xa3[\x84\xfc\x08>\x9ano\x9e\xe6\x98\xeb\x02\xb2\xee\xff%\xb3\x7f\x93\x14j\xdc\xa7w7Q\xd5\x1de\x0f#Ra\\\x9e\x04\xd9\x95=\xe0S?\x96\xe6w'
        b'\xe1\x10hb\xf8\x12\x00.\xe5\xc8\xc2*\x83\xa4\xfd\xc6@\x08c\x10\xdf\xd1$\x14\x84X3\x07\xc6S\xac\xd0\xb1\xf1\x1a\x14\xdcBe|L(S\xa1#\xff\xc2\x96s\xf0\x9f\xd1^Y\xa5\xd0\xbefo9`\xc3s\x98'
        b"\xc9\xdcHJ<\xbfrz*,\xdc\xab\xaa\xa8&JdA\xe0\x15\x1fT\xe5\xa0\xe3\xdf\xbdm\xe2w'\x0f\x14\x150\x7f\xeaq\x1d\x06\x1f%;\xe5\xce\x88\xe8?\xab\xd0\xda\xb38M5\x7f.\xd0gD\x0bFz\xb3"
        b";QW\xd2\x10z\xe7\xd3\xce\n\x86E\xebQ\x12V\xf6\x05\xb7\x81\xd1\x02\xbc\xb2\xa9rJ\xda\x0c\xb2\xa8\xa7\xfe_$n\x9aK\xd4\xbakvz\xa5+\x8c\xdd\xd5\xeao\x91\xd6\x03'\xb9\xc5f\xc8\x8a\xa6\n\x8e\x8f\\"
        b'\x8a\xb0\xe6,\x16\xa1\xc5b\tY_-5\xde\x8aH\xd6\x9b\xc8\xe7\xe6O:\xf7`\x9d\x10S\xbb\x90\x10SI\xec\x9e\xd1VN\x9a\x96\x0c\x9a\x0f\x1d#\x8c\x89M\xa5\x12q\xcf\x19\x92W\xef.\xd8hn\xf5$\xaa\xd1'
        b'\xfct\xe4\x17^N\xaf\x9d\xe3m,\x9aHO\xf7\x8c\x93\xef\x13\x82\xb0o\x11\xceQ\x16\x85\xaa\xc9\xf3\xe4\xefl\x97\xe1\xff\xf1j\xf1d\x86\xb1>\xc1\x04\xa2\x15\xd2F\xfb\xff\x1a\x8b4\xed\xda\xd2\xec\x8e\xb2\x8e\xffs\xea'
        b'\tn\xba\x06\xb1NB|\xec\xfdu\xf4\xcc\x1a\xb2E9\xf9\xa8\xb7\xdc\x9fr\x7f\xafejZ5EJ$Hs\xd9\x1dCBf\xf6\xde\n|\xea\x04\xa0\x1d\t[\xcf\xc0\xa6\x8a\xee\x1e\x1b\xf6Z\nU\x8a\xc8~\x1b'
        b'W\xa2F\xfc\xa7\xb2\xbc\xc6\xbb\xf8|\t\x1f(\xb4\xefP\t/a%\xda7\x80\x95\x14\x00\x05\x15\xda\xea\x98xd^7\n\x02\xdb\xa9N}\x12g\xff\xe8Z"7\x9dpz\xf5\xe4:\xca8\x1b\x1a\x9c\xb9\xc1%\xb5'
        b'\x80\xad\xff(P\xb7\x92\xf5fp\x013\xa5z\xc8\xc3\xf3\\\xa1\x00iaLTL\xef\xeagIbo\x9cy\xbeh\x99\x14\xa0\xfe*$\x1eR\x1cb\x17\x19o\xe5\xa6\x1be\xdd\xb8m \xe1\x8dp+\t\xcb\x1d\x92'
        b'\xbbTH\x18\x89[\xbc\xa4p\xbbq\x98\xe4`k\x1a\xd13a\xce\x84\xa1\xc2\x93w\xf7\x85d\xa7r\xb87\xb4V\xee\xd7\xe6?\xc8\x198Pp\xce\x84\x16>\x02?z\x99\xf6\xcf\xafL\xca\xcf\xe4\xadP/\xca;f'
        b'\x89\xdd\xeb\x19\x8e\xc9\xa7\x1f \xdb\xa7\xefm\xba\x01\xa8,\xb35D\xd9\\]Df&P8$\x0b\xa7\xfb\xff\x19\xcd\xecf\xbd\xbb\xe8\x84\x07\x1d\xc3\xa1\xeb\xa8C\x84\xb0\xf0bw\xaaV:o\x9f\x1b\xb0\x90\xc5\xa7\xd6'
        b"\xf9\xa3:\x94\x7f\xe5E\x7f\xb8\x8e\xd1\xe5\xa1\xf6\xbe\x1c\xed\x92\xb6\x9f\x97\xde\x89\xb3\xb9\xf6k\x83F\xdd\xe4'\xbc\xa5B\xfdk\x05\xc6\x17\xf8\x9d\xe3\xf9\xc3\xd5G\xa0\xb0+H\x90\x1es\xccpW\r2\xab\xbd\xf7\xdb\xd4"
        b'\x15r\x1f\xfbU\x01\x02\xf6@\xf4Q\\\x13R\xea\xeb\xdd\x0b\xce{`\xe99\t\xd6\xdc\x03g`O\xc8Q\xec0\xd1\xf0\xcb%7\xd8\\\xa4\xa4\xa8\x03\x89\xd7:\xbc\xfe\x82\x16\xa8Y\xa4,"\xfdQ\x18\xacB\x15o'
        b'\x10\x86x\xd5Y\xf9\n\xb4\x7f\xc56\xbcEf\xab0\x89\xc4\x1f>B\x00o\xe5\n\x96fk\xe7\xe8j\xd1\xcc\xbf\xf9\x97\xbep+I?$I_F3\xf4\x9bH\xc5\xd9\xf2\xe7\xc0\x147\x17\x15\xde2\xa8\xd1\xf7.'
        b'\x86\xa0G\xa6\xd8\xc5jS\xb3\x97\xab\x8d\x7fM\xf0\x99t\x9b\xd1\xc1W;?\\J<\xc9%\xb3\xac\x04\xa8\xa9 Y\xfe8\x9a\x9a:\xac\x10\x0c\xef\xf1&9\x9d\xaed\x85 _\x06\x9e\x915\xd6p|\xf3\xdeG\xda'
        b'\x10\x12\xfa\x1b\xa5\xa2\x93\xc2\xc4$\x11\xb4\xbc\x1c\xbc\xf8\xbex\xea\xe5~r\xbe\xfe\xb4\xe8e\xfc\xe1\xd9zqf\x176K\xb1\x9a\x88\xf0\xdaD\xb5\x03\x0b$\xc4a\xc4R=F\xb8\x06\x05\xd0\xb8\xe9\xf4X\x18\x9c\x1b\xac'
        b'8\xc0\x17\xab\xf63\xc4&\xb70\xf5\xae?\xf6\xac\x7fWv\xaf\x9a\x04\x8f\xdcF\xca\xfdj\xed\x89S_\xfe\xdc_\x95<\x93\xd0>r}K\x7fv\xd6\xdf\xd9\x01InV*\x85\xbaw\xa5\xa4\xde\xf2\xe5\xa09\xfa\xbc'
        b'\xe1\xeb\x80\xa4a\xf6\xd1\xb8\r\xf8\xfejN0\xca\xcdZ\x93\x04\x04e\x0e\x96\xe6\xa0h\x8e3\xd6\x7f#\x91\x05\x88b,\x9d\xb6v\xb8\x8e\xf8\xf5NS\x81t\xa7\x14\x94\xf7Ds\x82\xfd$\xc16\xe8\x9e\xa0\xa2\xf53'
        b'\xb7Mu\x9f\xd0O,_\xe0\xf3c\x1d\x93\xa8\x1e\xe4j\xfc\xa8\xa2d\xdc\x02D~\xfa\xfc\xb4n\x94c\xc6\xe18\x18\xe8\x96\x19\x8a\x1by\xf4\xa6\xe8\xd0V\x13\xa6K\xdc\xe5\x14\x10G\xc4"\xb1\x1b\xfe\x02\xb3ip\xec'
        b'`-\xd1\xc1\xf7\xea9\x17\x839N\xfc\x08\xe8\xd8\x84`\x14\xeb\xcf\x12\xdc\xea\x84\xa61\x13\xe3m\xd0\xc1\xc3\xb4\xe97\x13m\xf0C\x80}\xf8>\xfb\x96\xf5\xbd\x0e\xf9`Q\xf1\x9bj\xbd\x933\x96`\xff\x91\x19\xd8\x18'
        b"\xcd5U\xc8\xbd\x9fQ'\x1d5\xe6\xc6@\xa0z'\x86T9JyE\x0c\x96\x01\xdb\x96*\x1b:\x1e\xfb\x95\xe5\xf0\x87\x1a\xc8\n\x13#Po2\x13}k\x93\x03\xcd\xb2W\xfd\x18c\xf2j\xfc\x03\x06\x89\xc4\xbd{"
        b'\xdaF\xee3\xca&YK@\xa4i\x88\x91\xd5\xdbb\xc6Q\xfc\x03\xdcx\x97\xc1\x92-\xdb~vA\x19:x\xd6vig\xff\xd8\xa7\x13C\x13\xc2\x81-\xa5\xd0!\xf9\xd2\x9fz1\x94\xe3\xab\xab\xeeC\xfa$\x1e\x81'
        b"\xb4lrF:\x89\xb7\n\x95^<\x95\xedF\xad\xd2M\xee\xcd\xce\xe7\xb4\x99r\x13Q\xf5\x7f\xab[\xf0\xe1\xb3)\x0e)\x1c|\x19\x02\xee'~\xbfm\xaf\xb6r\x06Q\xad\x85\xc4\x86\xddC\x14\x9eI\xca$\xfa\xdc\xf2"
        b'#\xb9Z\x87\xc6\xf2\x12l7u{\xd1+\xf6S\n7\xf02U\x81^\xa5\x02\x89Ef\xec\xac\x86\x84\xf5\xff\x81\x8a\xb0\xed\x8e\xfb\x12\xc1\x14\x19DH@\xf9 \xbc\x88\xe2\xbb\xfc\x05\xda\x89\x1dY\x90\xef\xb1D\x1c\x81'
        b'\xe3uh`\x94\t9\xaahD\xe3\xb2Hq\x0b\\D\x08Y\xfd)\x1ajns\xc2M\xdc\xba$\xf2\x82\xbf!\xb2\x96\xaaL\x9c|\xeb\x17`\x9d\x03\x15\xbc\xb2\r\xf1\xd6G\xf9\x0e\x1e\xfe\xf8\x89\xdf\x96vA\xb1\x03'
        b'\xf6\xaf\xd6\xf2\x9d\x96!I\xf7\xf2\xf1zGf\x8f/\xbe\xd6{\xb2vu\'\xfcDm1\xfe\xc0\x1aJG\xa7\xfdb\x83GK:\xf9\xcd\xd0\xbe\xab^\x90\x8a&\x12\xe7"Y^\xd7\xde\xde\x19\xf8\xb9\n\xf2[\x06+'
        b'_\xbd>\x12\xe8\x86E\xf2\xc0\xe7\x8f\x1fj\x98&+D\xbf\x89@\xba\xd8\xba\x84`\x91\xff\xad\xbfs`\xb7\x0b\x88w)\xf7\x92\x8b\x98\x15#\x02\x06\xcb\xed6$\t\xe9\x9fZ\xc0Z\x10\xa2\xc45H\xe3\xc5\xfaxF'
        b'zeLS\xae~\x18\xe5\xb6>\x8f\x0f\xc0\xf4\xaf(;\x1a\x9d\xe9a\x8b\xff\xe6]\xb7M\xe7\xdcWH\xe8~\x08\xd0s\xe8\x90\xb6\xf6V\xd3H\xd5\xb7\xb4\x18\x1a\xca\xf6\xf2D\x1b9\xfa\x87\xb9\xdc\x03\x00$0\xebX'
        b'\xe7\xcef\xd4\x89\xaa\xa9\xc4\xe6\xd8O\xe8\x0c\x90\xfa\xf8\x99\xa7\xe4\xdc@b\xa4\xeb\xaa\xc4\x9d\x0e\xee\xb9h\xa9\xba\x91\xb5uX\x86\xb4\xdf\x07\tl\xdcU\xbf\x16\x06\xe8i\x92\xed\x04\xec\xad#\x88\x8e>@\xed\xcd\xfa\x8e'
        b'\xd1w\x9a>\xb1\xe9\xea[\x1fU\xd0\x83\xd7KD\xd1\x956\xc7\x8b\xc2JD\xefroc\x05\x94\x0ej\x07\xd6\x95\n\xb0\xcf\x7f\x91\xd2\xd3$\xbb\x19\xfbR\xa9r\xa4h\xa0\xd1\xa9\x16\xd6\xb9\xd7_\xe4\xf5\x11\x8b4\n'
        b'$\xee+}\x85H\xb5Ra\xc3T#Qm\x8bd\xfd\x06\xf7\x99\x98\xfe\xedc\xaa\x98\xdc\x04p<\xfe\x82\xa9u\xf5Jmm\xe8\xa0J\xf0\x9ef\xdd+\xc1d\xbd%\xa6\xc1{\xf6\x9c.<\xef\xe2WQb\x7f?'
        b'\xf0\xdd3\xfcP\xc0%\xc0\x84\xd1\xf1\xb1"\xafe\xb0\xb4\xfab\x9e\xeb\x00\xfe\xb5H\xf2\x19\xb7\xc1<\xfb\xb9\xad\xfb<\xbb(\x88]\xd6\x80\x95\xb4\x9d\xf7\x1e\xe0\xf2[r)~\xbb\xa9\xa7\xdegY\xd2a\xf3\xec,b'
        b'\xc7\xb2\xdc$\x0f\x8d\x96\x00{\xf4\xc9\xdc.\xec\xdfI\xe2\xc1<\xab_\x12\xe7q\xec\xb1u\xf8\x95(\xc6\xff k\x1a^)\xbb\x11\xabk,\n@\xbd\xe5\x84\xc0\xf5l?\xd9\x86\xa76N\x89\xba\x8d\x1f+\x17h\xae'
        b't\xb2!\xf7gw\xa3\xa2\xc7\x05\xfa\x85\x81\xb8\x04\x1bx\x8eM\xf7\x12\xff\x99al"\x01\xff\x98\x12\xa0\xe2\x010\xd1\xffh\xe4\xeaj\xa5\x13\x14\xb9\xde\x1c\x96\x04\xc5\x93m\x8b\x88\xd4\xe7\xe7\xe0~\xa5\xaeWd~.'
        b"\xff\xf2\x00\x02\xc8\xf1\xdborp%~{B\x19\x0f\xb1\x10@R\x0b\xcc\x86y\x91\xe2\xc1.\x199y\x96,2>\x8cX\xf54\xa1\xe5b\xb2y\xc3Q(\xd7\x88\x95N\xf8\xc8\\6\xb4\x94\xael'\x89\x93z\xa1"
        b'\xdd\xac(5\x0f\xdf$\xa1\xbdg7\xffI\xc3:\x9e\xdf\xfa\xe1{\tZ\xd8\x86\x95\x8e\xec\x1d\xdf\xbd\xd7T\xbc\xc9$\'?\x89 \xb1\xee\xf9b\x9a\x13*"\xbcq\x8b\x95\xcc\xbfA/d\\\r\r\x10\xb3d\x8d\xc1'
        b'k\xfdc\xee\xa3D\xae\xf5\xfe]a\x81\xa4\x11+\x17\x82S\xf0\xa2D\xc3Z\xa8?!\xe1\xd6W<$\xd4|\xd3\x90\x9a\x94\x19\xdf\xe2\x18\xa4\x0fv<\xe1\xb84\xe1\xe8\xe0/\xfe\xd5O\x89\x87\xd1\xe1"\x95\xf2\xcas'
        b"`\x9e]\x97c)\xc0\xd8&M\x82~=\xf0r\x99\xda\x12:a\xf8\xc4@\xe5\xc6\xfc\xd9\xd8\xbfu~\x9e?\x8d|W]\xa3\xdbE}\x92_\xfd1\x85\x01+\x9f\x1bng_\x08\xbc\xd3a\xa7\x0e(\xa2\x14'\xee"
        b'7\x05\x05\xa7g\x0c\xc9\xe4\x95o81!U\xb0\xd8\xcaT q\x82\x10\xc5!\xfe!w\xc1\xd3\x80\xad"\xc4\x0c\xb9=\x16\xc1Mk]P|\nz\x83\x9a.\xf5\xb7\\\x17\xe8^\xf6\xba\xf0\xc9\x98i\x11\xa6e\\'
        b'tkv\x03\x08\x9c\xed\x12\xe0!m<OG"\x8b\xed\x01\x08\x9c\xd3~\xff\x8a\xff\x8c9\xe8I\xf3\xa8d\xf4-I\xdbm\xeb\x9e\xd90/]h[\x8e=\xe2\x9f\xbb3\xb2\xd8!\xe5Q\xa0E^\x00\xa2*\xde\x97'
        b'\x98Yj\xcf\xcb\xc1\xc4\x10\xef|_V&.\xca:P\x1df0\xcf\x81\xa6\xfa\xac\xfa\xfd\x92%:z^^\x9a\x1fG\xa8ck\xf8\xc3\x04\x8f\xed\x9cK\xb4\xab\xf9\xae!\xf2d7\xd6Q\x8a\x19g\xb5\xf3(\xac\xda'
        b'\x87\xec\xf7*\xe1\xff@l\x08\x1fn\xa5{\x8f\x12~0\x10\xbc\x05<D=\x80~%\xb3\x06~\xaf1\x0c\xd4\x88;\x82O\x07=\xebc\xb3M\xf0\xe5\x18[\xab\xcc\n\xeb\x01\x12\xca\x01H\xb3>\xdeo!u\xd0\x16'
        b'\xf4\xc5\xe9*\xd5\x98\xd0<\x87+\x88\xf7\xb7\xd0JE\xb0\x9a:k\xbb`g\xe8\xe3j\xf2U;\x04_p\x1b\xa6\xd5\xd9b(\xa4\x0eK`Eg\xe1g\x17\xd6}h.\x92]\x0b\xaa\xa5\x94gy\xdd\xc4\xab\x80w'
        b'\xa9D\xad\xf1\x8c\xd4?\xa9\xbf\xd6\xfc5\xdbe$.\xd8\xae\x811$|8\x92\x95H\xe4\xc8\xd3\xd7\xba\x13\xa6\x8a\xe9\x14\xcf~/\xeb<J#y\xcf\xd0\xbcY~\x90\xc4R\xc9\xca3h\xfa\x92\xc4\xfb\xa1}q\x1c'
        b'H\xb8rCp%\x7fY\tR\xd2\xef\xad\xcf\x15KG\x08\xc2\xfat\xb2\xd7\x06\xba\xa7\x1d\xe5\rD\xc6U\xdc\x8b\x00\xa0\x16\xf7\x17\xb9yR\xdd\xb9\xc2\xa0e+\x9f\xfcI\xdc>\xd4\xa8\x9d-\xd8\x8d\x11\xeb,\xe3\xeb'
        b'\xfd\xa03\x02u\x9a\xbdk\xc1\n\xb3\xba\xf9\x1b\x19\x080\xee\xaf\xaf\x81\x03\xb4ps\xaaD\xa6\xca#!K\x92\x87\x86I\xcf\xf7\xda\xf8\x07\xfdx\x7f\x15\xd69\x86n(\xc9\xc8\xc7s\xa0\xe8gp:\xb9\xd6\x95\xf4\xab'
        b'"\x14\xe4\xae\x86\x91Y\xae\x1f7\xbb~7?\xdb\xa8\\1\'\\\xdb\xfdM\x83\xf1\x10xgbKt\xa7}\x8f\xfd\x00O\xf2pA\xfdS\xc1nU\xb5\xef\x07\x8e\x8d)\xf6\xf9ng%\xeed\x83`^\x8e\x9e.'
        b'\x08Cl\xb9\xc0T\xe0(\x04\xf6=+\xfd\xb19\rM\xc57h\xb8\xb7\xe3\x99p\x00\x97\xc5\x82t=Ee\x16\xcd\xea\x10h\xcc\xf0$\xf8\xfaC\xfe\xd1b\xb9`Bi\xc9M\x08sS\xfc\xd0\x8bO\x8b\\\xf1\xab'
        b'\xa4\xfc|\x89\xe1\x94\xcb\xf3\xeeo\n.4G\xbdb\x86\xf6B\x95CB$$\xc3r\xbbY\x03I\x88\x02\xd2\xa9C]3\x86\xfb\xe4Fg~z\xe4\x8d\xfa>\xd2\xf2\xe5y \xf3;\x1e\x12|\x9a\xe8\x0bD\xf6\xb6'
        b'\x92\xe3uY\xee\xb2^\x07\xaa\x94\xf2\x0c\x81:\xf6\xa6p\xaei\x07\x91\xe9\xc8):P\xec\x07\xce\xe67\x1b\x82\n!\xb53\xfb\xaf\xf0oRD\x91k%\x08\xed\x11\x85J\xb8\xcd\xaa\xb5o\x9e\xc1b\xdf\xa1jA\xeb'
        b'aD\xb6\x01D?\xaf\x01\xd6\x0c\x82n\x06\xed9I\xd7_wfW\xf6\x11\x03\xf1\xdf8\xd2jP-B\xfc\x0e\xae\xf6ml\xbe\xe4V\xdd\xcb\xfe\xa6\x1c\x18B\xc5~\xb3\x89_\xb5\xfd\x07\x84/\n_g!\x0fO'
        b"3'\xdd\xa1|\x93\x00\x1c\x85\x84\xcbL\xc7\xf4\xf1\xf1\xef\x95\xdb\xb4\xf7b\xfc=\xe8\x9c``\x01\x01\xe5\x1fw\xe8\xe5\x94\xfc\xb4\xd4\xec4\x16\xf1\xf6HJ\x1ca5\x1d\xea\x1f\xabi\xe0\xd1\xd1\xee|\xdd\xc7%\xdd}"
        b'\x1b\x8cU\xd4\x1b\x86\xf5T\\\x9c\xa4\x89\xe1\xf9\xb2\xcf\xf3\xd2\xcb\\\x13\xa1,\xe8\x7fu\xd1\x9e\x01\xf9\x86\xf3\x8e4|i$\xd3\xd5D\x12\x132\xb9U\xe5\xa9J\x88\x8f/\xd9o\xbd\x9e(G\x14\xde.\x84\xbe\xaa\xec'
        b'\xeaK\xf5OH-\x95\xdb\xccg\xe6=a\xb2\xcb\xe2i\xcc(3Q%}\x17\r\xdf\x8f\xd6\x91Z\xaa)u\xf0\x95H9\x8c\xd2R0\x8eV\xa6\xa1\xb7\x91\xd7\xd2\xb2\xf9\x06\x02R_u\xa8\xc3\xa6\xcc\x95/I\xbd'
        b';\x8f\xef\xdab\xc6wy\xe6}\x07\xaa\x84F\xec\xe3|Ps\xc4\xcd^\xb8U-H\xed\x1b\xbf\n\xd8~\xa8\xc9\xc8\xef\x1c\xfa\x93\xd2B\x98\xff9\x91 *\xf8C\xb3\xfc9a\x96Z*\xaa]o\x9a\x8d\xf3\x02\xc3'
        b'\xf7\xca\x0e\x937\xfa\xcd\x9f:M&+\x13pl\xe6<\x05\xd5\x94\xe1&\x8e\xec\xfe\x0bo\xe6eY- L\xc6V\x17{F\xe3O\x98A0^&\xec\xec\xe6\xe2"\xee\x82s\x9bXI\xd1/\xac\xa2&=yo'
        b'\xa2J<`\x01\x1fb\xaf\\k\x05\xaf\xa8\xcd\xab\x19\x9bKli{\x00\xb0\xf9\xbbF\xaeJ\x9b;\x84\xdcM\xed\xf0?\xf38ew\x16\x98\xd6S\xa2\x14\xe3\x84\x8b_Tc\xb12\xed\x8a\xcek\x1c\x9e\xa5\x97(\x13'
        b'\n\xbe\x15X\x023\xc1\x07\xab\xf1\xb1\xb8\xa89\xa0\xa08\xd6z\xad\xaa\xfdh$\xd8\x05\xa2\xc8y!\t\xf9\xb1\xf4\xc0s,o\x85\x7f\x1dN8\x0c\xc8\xcc\x95.\xdeL<\xf8\xd3u\xbc2$Y\x8c\xb8\x06\x1fjm'
        b"\x90F\x96\xa7\xd5\xa2\xde\xc3\xe0\xddh\xe3\xa0\x95\x19\xb4B]E1&\xd6\xbdy&QG\x0f\x8e\xcb4.\xf2\xd1 \x0b\xa0'IT\x97I\xaf\x86\xb3I\x07!\x8fA\x8b\xc3Y\x99\x1c\xd7\x98\x92u\x1d\xb0\xa2\x06&"
        b"\x19\xf1\xa6O\xdc\xee\xb8\xad\xf6\xa7\xde\xd1!7\x1b\xfbs\x1a\x94\x85Q\x81\x8e\x94\x1d^\xbeg\xbbE\x14\x84\x84\x9b\xe7?\xb2T\xc0z\xb8i\xd3\xfa\xa8\xfdJ.\xb8='\xf9sB\x95\x08\xbfC,O\xec\xcf\x0bd"
        b"\xbf`\xfbG\x89\x08\xa6I\xffW\x0f\x0e\xad<p\x1e_\xa7\x0b\xa1\xc3OR\x87E'\xf6\xf4}z<M\x10\xd3P\x9e\\\xb8+\x03&c\xd7\xfa\xfc\xb9\xeb?~\xa2&\x1a\x96\xa9H\xa1\xec\xb5\xc35\t;9\x95"
        b"\xf9\xa3kX\xa6\xe5[\x94\x1b}\x8a\t|\xf4\x8cj\xc2K\x14\xc3\xc2d9\xd7\x08v\xe4\x96\xeb\x9e\x9a\x0e\xb7h&\x9c\x0c/\x8d\xd00\x92\xc0b\x13!>\xd8o\xea\xe8w8\xa6\xcb\xe0\xcd1'L@\xbf\xe5C"
        b'\n\x819\x1a\xcd\x17\x96z\x161+oY\x16\\\xf7Z\xdf)M\xbe\xedd\x13\xef\xd9\n\xc8b\xecq9\x8eEd1\xd4\xb3[\xdbQ\xb3\xe8P\xcc\xb5\xce\xc14V*\xea\xcbi:\xe1(G\x98R\xc2u\r\xc5'
        b"'<\x91\x87\x18H5\xae\x15\x1aq\xe8x\xfbf\x95\x01\xfc^z\xc1%tv9\x002}\t-\xbaK\xe3\xe3k2#:\x8a\xb2b\xb62\xf3My\xd3\xe4\xd6FgM\x82h\\\xef\xfc\xc5\xbd\x12\x19\x8a{\x93"
        b"2d\xc5\xb6\xed\x80&\x96\xa0\xaf\x85\x1cn\x12K.\xa9\xb5\x88[\xb2\x15\r\xa2'\x81\xfd,Zx!\xae7\x87\xd4RR\x93\x8b\x96AQ) \x01'\xa3k^A\x8a\xcc\xda\x1e\xa9\x0b}\x9f\x19\x06\x1e\x04\x04\xb6"
        b"\x07\x1dY\xe9\xce\x87\xd7\x99\x10\x08>-\xf7jS'\xb9\xb0\xe0\xd8*\xbd\x15\x1f\x1d\xe8s\xfa\xf2\xe171,K\xe9\xb3\xc50<D\xbc\x90\x00\x0c\x84j_\xf8T\xe6\x82\x81\xf4\x9a\xf9\xdb\x94\xa7\x89\x0c\xdc\xf3|v"
        b'T\xb7\xbbhB\xde#\xeb\xfbz\x9fi\xa9m\r\xc6h\xe0\xe8\x94\x05\xc7\xde?\xecT\xa9qT\xbe\r\\!\xdc\xcbA\x8c\xd9\xdf\xaf\xc4\xc8\xf3\x05^\x1d\xb3\xee\xe9.&:\r\xadf\x90\x7fyX\xd9\x1e\xa6\x07\xf7'
        b'\xea\xb5\xc1\xbd\xb6A\t\x96\xd6\xd3\x12\x1e\x03\xa2\xcf\x0eoE\xf57\xe2\x96\xe7\r\xfdT\xce\xc7a\xa9\xe1\xe9\x10wo\xd7ac\x98Y\x95\xf5\x14\xf5,)\xb1\xb2wc\xd7\xa2A\xdf\xc9\x17\xa1r\xb4\x10\xc9\xcb\x1cr'
        b'\xfa\rL\xbf\x05\x9coF\xef\x1aAB\x87\xd2\xff\xeb\xc6\xb3\xf1\xf8\xde\xf0\x96m\xd9@\xe2\x06v\xdd\xbe\x0e\x90B\xef\xc5\x96wM\xb3\xbey7\xda\xae\xd9\xc3\xa6\xc2\xcb,\xcc\xd3pK\x13\xfa\xd1\xdeK\xf9r;?'
        b'\x8f\x8fsH\xdf\xd3\xa9\xb4\x91\xd8\xc9\x8f\xe4\x17\x03\xe6\xdb\xa7E\x03\xa2Is\x1cs\x02\xbf\xe5L-5J@\xe0\xf1\x07\xcc\xe5\xf8O\xe9\xa8\r\x04\x00~\xff+\xc7\xe3\x97Q\xdeA\xe2\x93\xc0\xe7\xd3I\x9a;5='
        b'\x01\xb2J=+g\t\xeeBZMr\xfeK\x06\xc8b\x04F\xf9xTB\xa5\xaa\x01\xf1\xb9\xca&\x1c\x88\xef\xd9\xfd\xcd.[\x86\x01\x80O\x8d\x8f\xe7rAs+_\xf8\x88Tx\x85\xc2\xad\xf6\xc63%\xcb\xd1\x1c'
        b"me\x86\xe5[\x16\xcc\x1f;\xe8\xdf\xfbG\x9e\xe7\x8e'\xf3\x84\x95\xa9\xb24\\\xef\xc4\xb0$\x02\xab\xf9\xf4I_\xca\\\x95\x16U\x83\x1d\xcf\xfba\xf0]\x96\x1eZ\x1d;\x16\x0fP\x87\xa4\xd2\x1f\xde\x9a\xc1\x81\xf7q"
        b"{G\x82\xde\x0f!\x07\xe6\xb1\xfe\x8e\xcb\xb7\\f2'S9\xaf\xe7\x83K\x96\xc2\xd0\x8d\x9e\x18\x04]\xa3\x88U\xbd\xbcAyo\x0f\xb3\x87\xb2u\xd0a\xbdG\xde\xe5\xac\x9a}\x027\xe6\xe8\x14\xd4'h5\xf7\xb4"
        b'\xbb+{\xa1\xfa%\xef\x91!\xa3\x9b\xd9\xf0\x7f\xa3\xdc\xdbrj\xb7\xda-d"\xb2\x98h-{ \x89.@\x9f\x85-(\x9d\xcf\x03"\x1e\'\xd6\xc8\xefx\x13(uJKP\x94A\xb1\xad\x17\x92\\[=\x03W'
        b'\x88\x15\xcc\x81\x8b\xc3\x01@=\x8b\r\xf0\xaaF\x84g\x06c _\x86]\xd8\xca\xc0\xb4\xc3L\x853\x96\x83\xbd\xec\x1f\x8b\xea\x89\x88c\xf7\xb8\xb1\xbb\xa8/\r\xa81\xa8\xfe\\\x98\x9d\xc6h\xd4\xadR\xb7\xe5\xd9\xdc\xe8'
        b'\xa5M\xa2\x1d\xe4T\x0fLLv\x8a\xb5_\xe5\xa7\xef\xa2\xb2\x01Q\xe8Y[J\x85\x0e.\xfcuF\xd8Qa\xa7\xd1$3@\x83\xf7[\xc8\xec\x10x2{h(\xc6\xe0\xb6m\x8f\xa2K\xd1\xb8\xdf\xda\xfffX1'
        b'n\x1b\\\xb6\xf3}\x1f\x1a\xe0m\r\xfdX\x1c\xc0B\xf6\xc8\xa6Y\xe6\x9f\xe6~\xa8\xea\xa0\x12\xa0\xbe\n\xfe\xe6\xcbX\xeaz\xa1g\xbfQ\x18jG\xb3\x17R+\xa1\xba\x1f\xa4\xe5$\x14m\x87\xdc[\x94\xee\xedbe'
        b'\xbc\xc6i\x06\x9d\xc3<\xe3\xc7\x1c\xd2\x8e\x80\xc6\xf8\x9c\xb6\xb7\xd9\x960S\xfek\xc7\xf8Y`,<\xdau\xd2\xe8 P ?Vz\x89\x9a\x8a0\xab!Tu+\x91X\x0cE~\xff\xe5\x17.\xe1\x04\xbf\x13\x9d\x8a'
        b'{\x18\xae\x19.\xa2s{\x83!FML9\xd0\xe6`\xd75*\xb2\x1dG7h\x0ba\xa0U5\xe2\x08\xe0\x9b\xbb=)\x08\x1e\x1f\xafg\x18\xe0\xc5\xb5H\xa8f\xc8\xdev\x82\xf5\xca(\xc5\xb0\xef\xf4\x85f\x89\xf0'
        b'\x858\xc0\xedS\x1f\xfe\xa5\xaf\xfarqSP]\x84"\xfe!\x18\xea"M\xaaZ\x1d\xa30\xd1\xbbQ5\xd0\x87P)F~\xaa:\x82\x9esk)\xaa4\x1d\x91\n2#\x18z\'\x9a\xea\x14\xef)\x8a\x9dr\xe0'
        b'\x91\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r'
        b'\x05\x00\x00\x00\xfa\x16<frozen fintech.swift>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
